@@ -18,6 +18,17 @@ pub(crate) fn get_branch_upstream<'repo>(branch: &Branch<'repo>) -> Res<Option<B
     }
 }
 
+pub(crate) fn get_remote_name(repo: &Repository, upstream: &Branch) -> Res<String> {
+    let branch_full = String::from_utf8_lossy(upstream.get().name_bytes());
+
+    Ok(String::from_utf8_lossy(
+        repo.branch_remote_name(&branch_full)
+            .map_err(Error::GetRemote)?
+            .deref(),
+    )
+    .into_owned())
+}
+
 /// If the branch has an upstream, returns the remote name and branch name in that order.
 /// Returns "." as remote if the current branch has no remote upstream.
 ///
@@ -37,25 +48,12 @@ pub(crate) fn get_upstream_components(repo: &Repository) -> Res<Option<(String,
         return Ok(None);
     };
 
-    let branch = String::from_utf8(upstream.get().shorthand_bytes().to_vec())
-        .map_err(Utf8Error::String)
-        .map_err(Error::BranchNameUtf8)?;
+    let branch = String::from_utf8_lossy(upstream.get().shorthand_bytes()).into_owned();
 
     if upstream.get().is_remote() {
-        let branch_full = str::from_utf8(upstream.get().name_bytes())
-            .map_err(Utf8Error::Str)
-            .map_err(Error::BranchNameUtf8)?;
-        let remote = String::from_utf8(
-            repo.branch_remote_name(branch_full)
-                .map_err(Error::GetRemote)?
-                .deref()
-                .to_vec(),
-        )
-        .map_err(Utf8Error::String)
-        .map_err(Error::RemoteNameUtf8)?;
-
-        let remote_prefix = format!("{remote}/");
-        Ok(Some((remote, branch.replace(&remote_prefix, ""))))
+        let remote_name = get_remote_name(repo, &upstream)?;
+        let remote_prefix = format!("{remote_name}/");
+        Ok(Some((remote_name, branch.replace(&remote_prefix, ""))))
     } else {
         Ok(Some((".".into(), branch)))
     }
@@ -66,21 +64,30 @@ pub(crate) fn get_upstream_shortname(repo: &Repository) -> Res<Option<String>> {
         return Ok(None);
     };
     Ok(Some(
-        String::from_utf8(upstream.get().shorthand_bytes().to_vec())
-            .map_err(Utf8Error::String)
-            .map_err(Error::GetCurrentBranchUpstreamUtf8)?,
+        String::from_utf8_lossy(upstream.get().shorthand_bytes()).into_owned(),
     ))
 }
 
+pub(crate) fn get_upstream_remote(repo: &Repository) -> Res<Option<String>> {
+    let Some(upstream) = get_upstream(repo)? else {
+        return Ok(None);
+    };
+
+    if upstream.get().is_remote() {
+        let remote_name = get_remote_name(repo, &upstream)?;
+        Ok(Some(remote_name))
+    } else {
+        Ok(None)
+    }
+}
+
 pub(crate) fn get_push_remote(repo: &Repository) -> Res<Option<String>> {
     let push_remote_cfg = head_push_remote_cfg(repo)?;
     let config = repo.config().map_err(Error::ReadGitConfig)?;
 
     match config.get_entry(&push_remote_cfg) {
         Ok(entry) => Ok(Some(
-            String::from_utf8(entry.value_bytes().to_vec())
-                .map_err(Utf8Error::String)
-                .map_err(Error::ReadGitConfigUtf8)?,
+            String::from_utf8_lossy(entry.value_bytes()).into_owned(),
         )),
         Err(e) if e.class() == git2::ErrorClass::Config => get_default_push_remote(repo),
         Err(e) => Err(Error::ReadGitConfig(e)),
@@ -93,9 +100,7 @@ pub(crate) fn get_default_push_remote(repo: &Repository) -> Res<Option<String>>
 
     match config.get_entry(push_default_cfg) {
         Ok(entry) => Ok(Some(
-            String::from_utf8(entry.value_bytes().to_vec())
-                .map_err(Utf8Error::String)
-                .map_err(Error::ReadGitConfigUtf8)?,
+            String::from_utf8_lossy(entry.value_bytes()).into_owned(),
         )),
         Err(e) if e.class() == git2::ErrorClass::Config => Ok(None),
         Err(e) => Err(Error::ReadGitConfig(e)),
