@@ -1,12 +1,12 @@
 use super::{Action, OpTrait};
-use crate::{error::Error, items::TargetData, state::State};
+use crate::{app::State, error::Error, item_data::ItemData};
 use std::rc::Rc;
 
 pub(crate) struct CopyHash;
 impl OpTrait for CopyHash {
-    fn get_action(&self, target: Option<&TargetData>) -> Option<Action> {
+    fn get_action(&self, target: &ItemData) -> Option<Action> {
         match target {
-            Some(TargetData::Commit(r)) => copy_hash(r.clone()),
+            ItemData::Commit { oid, .. } => copy_hash(oid.clone()),
             _ => None,
         }
     }
@@ -20,14 +20,14 @@ impl OpTrait for CopyHash {
 }
 
 fn copy_hash(r: String) -> Option<Action> {
-    Some(Rc::new(move |state, _term| {
-        state.close_menu();
-        match &mut state.clipboard {
+    Some(Rc::new(move |app, _term| {
+        app.close_menu();
+        match &mut app.state.clipboard {
             Some(cb) => {
                 cb.set_text(r.clone()).map_err(Error::Clipboard)?;
-                state.display_info("Commit hash copied to clipboard");
+                app.display_info("Commit hash copied to clipboard");
             }
-            None => state.display_error("Clipboard not available"),
+            None => app.display_error("Clipboard not available"),
         }
         Ok(())
     }))
