@@ -58,6 +58,8 @@ pub(crate) enum Op {
     CommitAmend,
     CommitExtend,
     FetchAll,
+    FetchPushRemote,
+    FetchUpstream,
     FetchElsewhere,
     LogCurrent,
     PullFromPushRemote,
@@ -149,6 +151,8 @@ impl Op {
             Op::CommitExtend => Box::new(commit::CommitExtend),
             Op::FetchAll => Box::new(fetch::FetchAll),
             Op::FetchElsewhere => Box::new(fetch::FetchElsewhere),
+            Op::FetchPushRemote => Box::new(fetch::FetchPushRemote),
+            Op::FetchUpstream => Box::new(fetch::FetchUpstream),
             Op::LogCurrent => Box::new(log::LogCurrent),
             Op::PullFromPushRemote => Box::new(pull::PullFromPushRemote),
             Op::PullFromUpstream => Box::new(pull::PullFromUpstream),
