@@ -7,7 +7,7 @@ use crate::{
     screen,
 };
 use core::str;
-use std::{path::Path, process::Command, rc::Rc};
+use std::{path::Path, process::Command, rc::Rc, sync::Arc};
 
 pub(crate) struct Show;
 impl OpTrait for Show {
@@ -22,19 +22,24 @@ impl OpTrait for Show {
                 kind: RefKind::Branch(oid),
                 ..
             } => goto_show_screen(oid.clone()),
-            ItemData::File(u) => editor(u.as_path(), None),
-            ItemData::Delta { diff, file_i } => editor(
-                Path::new(&diff.text[diff.file_diffs[*file_i].header.new_file.clone()]),
-                None,
-            ),
+            ItemData::Untracked(u) => editor(u.as_path(), None),
+            ItemData::Delta { diff, file_i } => {
+                let file_path = &diff.file_diffs[*file_i].header.new_file;
+                let path: &str = &file_path.fmt(&diff.text);
+                editor(Path::new(path), None)
+            }
             ItemData::Hunk {
                 diff,
                 file_i,
                 hunk_i,
-            } => editor(
-                Path::new(&diff.text[diff.file_diffs[*file_i].header.new_file.clone()]),
-                Some(diff.file_line_of_first_diff(*file_i, *hunk_i) as u32),
-            ),
+            } => {
+                let file_path = &diff.file_diffs[*file_i].header.new_file;
+                let path: &str = &file_path.fmt(&diff.text);
+                editor(
+                    Path::new(path),
+                    Some(diff.file_line_of_first_diff(*file_i, *hunk_i) as u32),
+                )
+            }
             ItemData::Stash { stash_ref, .. } => goto_show_stash_screen(stash_ref.clone()),
             _ => None,
         }
@@ -53,7 +58,7 @@ fn goto_show_screen(r: String) -> Option<Action> {
         app.close_menu();
         app.state.screens.push(
             screen::show::create(
-                Rc::clone(&app.state.config),
+                Arc::clone(&app.state.config),
                 Rc::clone(&app.state.repo),
                 term.size().map_err(Error::Term)?,
                 r.clone(),
@@ -69,7 +74,7 @@ fn goto_show_stash_screen(stash_ref: String) -> Option<Action> {
         app.close_menu();
         app.state.screens.push(
             screen::show_stash::create(
-                Rc::clone(&app.state.config),
+                Arc::clone(&app.state.config),
                 Rc::clone(&app.state.repo),
                 term.size().map_err(Error::Term)?,
                 stash_ref.clone(),
