@@ -2,19 +2,19 @@ use super::*;
 
 #[test]
 pub(crate) fn quit() {
-    let app = snapshot!(TestContext::setup_init(), "q");
+    let app = snapshot!(setup_clone!(), "q");
     assert!(app.state.quit);
 }
 
 #[test]
 pub(crate) fn quit_from_menu() {
-    let app = snapshot!(TestContext::setup_init(), "hq");
+    let app = snapshot!(setup_clone!(), "hq");
     assert!(!app.state.quit);
 }
 
 #[test]
 pub(crate) fn confirm_quit_prompt() {
-    let mut ctx = TestContext::setup_init();
+    let mut ctx = setup_clone!();
     ctx.config().general.confirm_quit.enabled = true;
 
     let app = snapshot!(ctx, "q");
@@ -23,7 +23,7 @@ pub(crate) fn confirm_quit_prompt() {
 
 #[test]
 pub(crate) fn confirm_quit() {
-    let mut ctx = TestContext::setup_init();
+    let mut ctx = setup_clone!();
     ctx.config().general.confirm_quit.enabled = true;
 
     let app = snapshot!(ctx, "qy");
